import type Map from '../map';
import type { IControl } from './control';
declare type Options = {
    container?: HTMLElement;
};
/**
 * A `FullscreenControl` control contains a button for toggling the map in and out of fullscreen mode.
 *
 * @implements {IControl}
 * @param {Object} [options]
 * @param {HTMLElement} [options.container] `container` is the [compatible DOM element](https://developer.mozilla.org/en-US/docs/Web/API/Element/requestFullScreen#Compatible_elements) which should be made full screen. By default, the map container element will be made full screen.
 *
 * @example
 * map.addControl(new maplibregl.FullscreenControl({container: document.querySelector('body')}));
 * @see [View a fullscreen map](https://maplibre.org/maplibre-gl-js-docs/example/fullscreen/)
 */
declare class FullscreenControl implements IControl {
    _map: Map;
    _controlContainer: HTMLElement;
    _fullscreen: boolean;
    _fullscreenchange: string;
    _fullscreenButton: HTMLButtonElement;
    _container: HTMLElement;
    constructor(options: Options);
    onAdd(map: Map): HTMLElement;
    onRemove(): void;
    _checkFullscreenSupport(): boolean;
    _setupUI(): void;
    _updateTitle(): void;
    _getTitle(): any;
    _isFullscreen(): boolean;
    _changeIcon(): void;
    _onClickFullscreen(): void;
}
export default FullscreenControl;
//# sourceMappingURL=fullscreen_control.d.ts.map